function [data, auxData, metaData, txtData, weights] = mydata_Ninox_novaeseelandiae

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Aves'; 
metaData.order      = 'Strigiformes'; 
metaData.family     = 'Strigidae';
metaData.species    = 'Ninox_novaeseelandiae'; 
metaData.species_en = 'Morepork'; 

metaData.ecoCode.climate = {'Cfb'};
metaData.ecoCode.ecozone = {'TAz', 'TAt'};
metaData.ecoCode.habitat = {'0iTf'};
metaData.ecoCode.embryo  = {'Tnwf','Tnsf'};
metaData.ecoCode.migrate = {};
metaData.ecoCode.food    = {'biCi', 'biCv'};
metaData.ecoCode.gender  = {'Dg'};
metaData.ecoCode.reprod  = {'O'};

metaData.T_typical  = C2K(39.5); % K, body temp
metaData.data_0     = {'ab'; 'ax'; 'aR'; 'am'; 'Wwb'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-Ww'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author   = {'Bas Kooijman'};    
metaData.date_subm = [2018 09 02];              
metaData.email    = {'bas.kooijman@vu.nl'};            
metaData.address  = {'VU University Amsterdam'};   

metaData.author_mod_1   = {'Bas Kooijman'};    
metaData.date_mod_1     = [2022 11 29];              
metaData.email_mod_1    = {'bas.kooijman@vu.nl'};            
metaData.address_mod_1  = {'VU University Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'starrlight@tecnico.ulisboa.pt'}; 
metaData.date_acc    = [2022 11 29]; 

%% set data
% zero-variate data

data.ab = 25;        units.ab = 'd';    label.ab = 'age at birth';                 bibkey.ab = 'guess';   
  temp.ab = C2K(33); units.temp.ab = 'K'; label.temp.ab = 'temperature';
data.tx = 42;        units.tx = 'd';    label.tx = 'time since birth at fledging'; bibkey.tx = 'Gubb1978';   
  temp.tx = C2K(39.5); units.temp.tx = 'K'; label.temp.tx = 'temperature';
data.tR = 3*365;       units.tR = 'd';    label.tR = 'time since birth at 1st brood';bibkey.tR = 'Wiki';
  temp.tR = C2K(39.5); units.temp.tR = 'K'; label.temp.tR = 'temperature';
data.am = 29*365;    units.am = 'd';    label.am = 'life span';                    bibkey.am = 'guess';   
  temp.am = C2K(39.5); units.temp.am = 'K'; label.temp.am = 'temperature'; 

data.Wwb = 16;     units.Wwb = 'g';   label.Wwb = 'wet weight at birth';         bibkey.Wwb = 'Gubb1978';
data.Wwi = 190;    units.Wwi = 'g';   label.Wwi = 'ultimate wet weight for females'; bibkey.Wwi = 'Wiki';
  comment.Wwi = '170 till 216 g';
data.Wwim = 145;   units.Wwim = 'g';  label.Wwim = 'ultimate wet weight for males'; bibkey.Wwim = 'Wiki';
  comment.Wwim = '140 till 156 g';

data.Ri  = 2/365;    units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';         bibkey.Ri  = 'Gubb1978';   
  temp.Ri = C2K(39.5); units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
  
% uni-variate data
% t-W data
data.tW1 = [ ... % time since birth (d), wet weight (g)
  1  16
  7  51
 14  88.5
 21 138
 28 160
 35 169
 91 188
139 170];  
units.tW1   = {'d', 'g'};  label.tW1 = {'time since birth', 'wet weight'};  
temp.tW1    = C2K(39.5);  units.temp.tW1 = 'K'; label.temp.tW1 = 'temperature';
bibkey.tW1 = 'Gubb1978';
comment.tW1 = 'Data for owl 1';
%
data.tW2 = [ ... % time since birth (d), wet weight (g)
  1  16
  7  44
 14  87.5
 21 120
 28 157
 35 165
 91 177
139 170];  
units.tW2   = {'d', 'g'};  label.tW2 = {'time since birth', 'wet weight'};  
temp.tW2    = C2K(39.5);  units.temp.tW2 = 'K'; label.temp.tW2 = 'temperature';
bibkey.tW2 = 'Gubb1978';
comment.tW2 = 'Data for owl 2';

%% set weights for all real data
weights = setweights(data, []);
weights.tW1 = 10 * weights.tW1; 
weights.tW2 = 10 * weights.tW2; 
weights.Wwb = 5 * weights.Wwb; 
weights.Wwi = 5 * weights.Wwi; 

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
txtData.comment = comment;

%% Group plots
set1 = {'tW1','tW2'}; subtitle1 = {'Data for owl 1, 2'};
metaData.grp.sets = {set1};
metaData.grp.subtitle = {subtitle1};

%% Discussion points
D1 = 'Body temperature is guessed';
D2 = 'Males are assumed to differ from females by {p_Am} only';
D3 = 'mod_1: v is reduced';
metaData.discussion = struct('D1',D1, 'D2',D2, 'D3',D3);

%% Links
metaData.links.id_CoL = '73ZSC'; % Cat of Life
metaData.links.id_ITIS = '555480'; % ITIS
metaData.links.id_EoL = '45517852'; % Ency of Life
metaData.links.id_Wiki = 'Ninox_novaeseelandiae'; % Wikipedia
metaData.links.id_ADW = 'Ninox_novaeseelandiae'; % ADW
metaData.links.id_Taxo = '54695'; % Taxonomicon
metaData.links.id_WoRMS = ''; % WoRMS
metaData.links.id_avibase = 'E8E9C26DAFD46DC2'; % avibase
metaData.links.id_birdlife = 'morepork-ninox-novaeseelandiae'; % birdlife
metaData.links.id_AnAge = ''; % AnAge


%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Ninox_novaeseelandiae}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{../../../bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Gubb1978'; type = 'Article'; bib = [ ... 
'author = {Gubb, C.}, ' ... 
'doi = {10.1111/j.1748-1090.1978.tb00260.x}, ' ...
'year = {1978}, ' ...
'title = {Hatching and hand-rearing the Boobook owl}, ' ...
'journal = {International Zoo Yearbook}, ' ...
'volume = {18}, ' ...
'pages = {200-201}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];

